<template>
    <div class="full-page bg">
        <div class="search-container" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
            element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
            <el-form ref="form" :model="searchForm" label-width="auto" style="width: 100%">
                <el-row :gutter="20">
                  <!-- <el-col :span="5">
                    <el-form-item label="责任单位">
                      <el-input v-model="querys[1].value" clearable placeholder="请输入责任单位">
                      </el-input>
                    </el-form-item>
                  </el-col> -->
                  <el-col :span="5">
                    <el-form-item label="专项小组">
                      <el-select
                        v-model="querys[2].value"
                        placeholder="请选择专项小组"
                        clearable
                        style="width: 100%"
                      >
                        <el-option
                          v-for="(item, index) in groupNameOptions"
                          :key="index"
                          :label="item.label"
                          :value="item.value"
                        ></el-option>
                      </el-select>
                    </el-form-item>
                  </el-col>
                  <el-col :span="8">
                    <el-form-item label="填报时间">
                      <el-date-picker
                        v-model="querys[0].value"
                        :default-time="['00:00:00', '23:59:59']"
                        align="right"
                        clearable
                        end-placeholder="结束日期"
                        placeholder="请选择填报日期"
                        start-placeholder="开始日期"
                        type="datetimerange"
                        value-format="yyyy-MM-dd HH:mm:ss"
                      >
                      </el-date-picker>
                    </el-form-item>
                  </el-col>
                    <el-col :span="2">
                        <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch(1)">
                            搜索
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" class="main-table-container flex">
            <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
                <div style="margin-bottom: 10px" ref="btnPanel">
                  <el-button type="danger" plain :class="['btn', 'btn-plus', auditStatus ? '' : 'btn-reviewed']"
                             @click="getTableData(false)">
                    待审核
                  </el-button>
                  <el-button slot="reference" type="success" plain
                             :class="['btn', 'btn-delete', auditStatus ? 'btn-audited' : '']" @click="getTableData(true)">
                    已审核
                  </el-button>
                </div>
                <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
                    <el-table stripe size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
                        :max-height="tableMaxHeight" :style="{ width: '100%' }"
                        >
                      <el-table-column type="index" width="60" label="序号" align="center"
                                       :selectable="selectHandle"></el-table-column>
                        <!-- <el-table-column prop="unitName" min-width="100" show-overflow-tooltip label="责任单位"
                            align="center">
                        </el-table-column> -->
                        <el-table-column prop="groupName" min-width="100" show-overflow-tooltip label="专项小组"
                            align="center">
                        </el-table-column>
                        <el-table-column
                          align="center"
                          label="填报时间"
                          prop="createTime"
                          show-overflow-tooltip
                        >
                        </el-table-column>
                        <el-table-column show-overflow-tooltip label="审核状态" align="center">
                            <template v-slot="{ row }">
                                <el-tag :type="!row.status
                                    ? 'info'
                                    : row.status === 1 ||
                                        row.status === 3 ||
                                          row.status === 5
                                        ? ''
                                        : row.status === 2 ||
                                            row.status === 4 ||
                                              row.status === 6
                                            ? 'danger'
                                            : row.status === 7
                                                ? 'success'
                                                : ''
                                    ">
                                    {{ getDictName('sjggqk_shzt', row.status) }}
                                </el-tag>
                            </template>
                        </el-table-column>
                        <el-table-column show-overflow-tooltip align="center" fixed="right" width="180" label="操作">
                            <template v-slot="{row}">
                                <el-link v-if="row.status === 1" icon="el-icon-s-check" type="primary" :underline="false"
                                    class="cloumn-btn" @click="
                                        handleDbClick(row, '审核')
                                        ">
                                    审核
                                </el-link>
                                <el-link v-if="row.status === 2 || row.status === 3" icon="el-icon-refresh-left" type="danger"
                                :underline="false" class="cloumn-btn withdraw" @click="revocation(row)">
                                    撤回
                                </el-link>
                                <el-link icon="el-icon-view" type="primary" :underline="false" class="cloumn-btn"
                                    @click="
                                        handleDbClick(row, '详情')
                                        ">
                                    详情
                                </el-link>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="queryParam.pageBean"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </el-col>
        </el-row>
        <EntryDialog ref="ProjectsDialog" @getData="getData"></EntryDialog>
    </div>
</template>

<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import utils from '@/utils.js'
import projectsAPI from '@/api/ReformSituation/reformAudit'
import EntryDialog from './components/entryDialog.vue'
import api from '@/api/ReformSituation/municipal'
export default {
    name: 'DepartmentAudit',
    components: {
        pagination,
        EntryDialog
    },
    mixins: [TableMixin],
    data() {
        return {
            markLoading: false,
            searchForm: {},
            loading: false,
            tableData: [],
            multipleSelection: [],
            auditStatus: false,
            querys: [
                {
                  group: 'main',
                  operation: 'BETWEEN',
                  parentGroup: '',
                  property: 'CREATE_TIME_',
                  relation: 'AND',
                  value: ''
                },
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'unit_name_',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'group_name_',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'IN',
                    parentGroup: '',
                    property: 'status_',
                    relation: 'AND',
                    value: [1],
                },
            ],
            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                },
            },
          groupNameOptions: [
            {
              label: '党建统领体制改革专项小组',
              value: '党建统领体制改革专项小组'
            },
            {
              label: '经济体制改革专项小组',
              value: '经济体制改革专项小组'
            },
            {
              label: '社会民生领域改革专项小组',
              value: '社会民生领域改革专项小组'
            },
            {
              label: '民主与法制领域改革专项小组',
              value: '民主与法制领域改革专项小组'
            },
            {
              label: '文化体制改革专项小组',
              value: '文化体制改革专项小组'
            },
            {
              label: '平安法治领域改革专项小组',
              value: '平安法治领域改革专项小组'
            }
            // {
            //   label: '其他',
            //   value: '其他'
            // }
          ]
        }
    },
    created() {
        this.getData()
    },
    mounted() { },
    methods: {
        // 状态按钮筛选
        getTableData(val) {
          if (this.auditStatus != val) {
            this.auditStatus = val
            this.queryParam.pageBean.page = 1
            this.querys[3].value = this.auditStatus ? [2, 3,4,5,6,7] : [1]
            this.handleSearch(1)
          }
        },

        selectHandle(row) {
            if (row.status != 1) {
                return true
            }
        },

        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        handleSearch(page) {
            this.queryParam.querys = []
            this.querys.forEach((item) => {
                if (item.value !== undefined) {
                    this.queryParam.querys.push(item)
                }
            })
            if (page) {
                this.queryParam.pageBean.page = page
            }
            this.getData()
        },

        // 撤回
        revocation(item) {
            let data = {
                status: 1,
                id: item.id,
                approvalResults: 2
            }
            this.$confirm('确认执行撤销操作吗？', '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'error'
            }).then(() => {
                this.markLoading = true
                api.getUpdateStatus(data).then(res => {
                    if (res.state) {
                        this.$message.success('撤销操作成功')
                        this.handleSearch(1)
                    }
                    this.markLoading = false
                })

            }).catch(() => { })
        },
        //获取数据
        getData() {
            this.loading = true
            this.tableData = []
            this.queryParam.querys = this.querys
            api.getTableData(this.queryParam, false).then(res => {
                if (res.rows) {
                    this.tableData = res.rows
                    this.queryParam.pageBean.page = res.page
                    this.queryParam.pageBean.total = res.total
                    this.$set(this.tableData)
                    this.loading = false
                }
            })
        },

        //修改
        handleDbClick(data, title) {
            this.$refs.ProjectsDialog.open(data, title)
        },

        //展示数量
        handleSizeChange(val) {
            this.queryParam.pageBean.pageSize = val
            this.handleSearch(1)
        },
        //表格页数
        handleCurrentChange(val) {
            this.queryParam.pageBean.page = val
            this.handleSearch(val)
        },
    },
}
</script>

<style lang="scss" scoped>

.wait-updata-btn {
    border: 1px solid #f56c6c !important;

    &:hover {
        background-color: #f56c6c !important;
        color: #fff !important;
        border-color: #f56c6c !important;
    }
}

.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(2) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    // &:nth-child(2):hover {
    //   background-color: #f56c6c;
    //   color: #fff;
    //   border-color: #f56c6c;
    // }
    /deep/ i,
    span {
        font-size: 16px;
    }
}
</style>
